'use strict';

var jsonfile = require('jsonfile');
var path = require('path');
var fs = require('fs');
var chalk = require('chalk');

var util = require('util');
module.exports = exports = util;

var confFilePath = path.resolve(process.cwd(), '.websakconfig');
util.readConfig = function () {
  if (util.fileExists(confFilePath)) {
    return jsonfile.readFileSync(confFilePath);
  } else {
    return {};
  }
};

util.saveConfig = function (conf) {
  util.saveJSON(confFilePath, conf);
};

util.saveJSON = function (filePath, obj) {
  jsonfile.writeFileSync(filePath, obj, { spaces: 2 });
};

util.fileExists = function (filePath) {
  try {
    fs.accessSync(filePath, fs.R_OK | fs.W_OK);
    return true;
  } catch (e) {
    return false;
  }
};

util.error = function () {
  var str = util.format.apply(util, arguments);
  str = chalk.red.bold(str);
  console.error(str);
};

//or using yargs.commandDir('commands'), current yargs v4.7.1 not supported
util.addCommands = function (yargs, commandDirPath) {
  var files = fs.readdirSync(commandDirPath);
  files.forEach(function (file) {
    var filePath = path.join(commandDirPath, file);
    var stats = fs.lstatSync(filePath);
    if (!stats || !stats.isFile()) return;
    yargs.command(require(filePath));
  });
};